@@ -4,6 +4,6 @@ const createFromBuffer = require("@dprint/formatter").createFromBuffer;
 const getBuffer = require("./index").getBuffer;
 
 const formatter = createFromBuffer(getBuffer());
-const result = formatter.formatText("file.toml", "key   =    value");
+const result = formatter.formatText("file.toml", "key   =   5");
 
-assert.strictEqual(result, "key = value\n");
+assert.strictEqual(result, "key = 5\n");
